#include <winver.h>

VS_VERSION_INFO VERSIONINFO
  FILEVERSION 1,6,1,0
  PRODUCTVERSION 1,6,1,0
  FILEFLAGSMASK 0
  FILEFLAGS 0
  FILEOS VOS__WINDOWS32
  FILETYPE VFT_DLL
  FILESUBTYPE VFT2_UNKNOWN
  BEGIN
    BLOCK "StringFileInfo"
    BEGIN
      BLOCK "040904B0"
      BEGIN
	VALUE "CompanyName", "none"
	VALUE "FileDescription", "libenchant"
	VALUE "FileVersion", "1.6.1.0"
	VALUE "InternalName", "libenchant"
	VALUE "OriginalFilename", "libenchant.dll"
	VALUE "ProductName", "libenchant"
	VALUE "ProductVersion", "1.6.1"
      END
    END
    BLOCK "VarFileInfo"
    BEGIN
      VALUE "Translation", 0x409, 1200
    END
  END
