EXPORTS
fd_ostream_create
fd_ostream_flush
fd_ostream_free
fd_ostream_write_mem

file_ostream_create
file_ostream_flush
file_ostream_free
file_ostream_write_mem

html_ostream_write_mem
html_ostream_flush
html_ostream_free
html_ostream_begin_span
html_ostream_end_span
html_ostream_get_hyperlink_ref
html_ostream_set_hyperlink_ref
html_ostream_flush_to_current_style
html_ostream_create

html_styled_ostream_begin_use_class
html_styled_ostream_create
html_styled_ostream_end_use_class
html_styled_ostream_flush
html_styled_ostream_flush_to_current_style
html_styled_ostream_free
html_styled_ostream_get_hyperlink_id
html_styled_ostream_get_hyperlink_ref
html_styled_ostream_set_hyperlink
html_styled_ostream_write_mem

iconv_ostream_create
iconv_ostream_flush
iconv_ostream_free
iconv_ostream_write_mem

memory_ostream_contents
memory_ostream_create
memory_ostream_flush
memory_ostream_free
memory_ostream_write_mem

noop_styled_ostream_begin_use_class
noop_styled_ostream_create
noop_styled_ostream_end_use_class
noop_styled_ostream_flush
noop_styled_ostream_flush_to_current_style
noop_styled_ostream_free
noop_styled_ostream_get_hyperlink_ref
noop_styled_ostream_get_hyperlink_id
noop_styled_ostream_set_hyperlink
noop_styled_ostream_write_mem

ostream_flush
ostream_free
ostream_printf
ostream_vprintf
ostream_write_mem
ostream_write_str

styled_ostream_begin_use_class
styled_ostream_end_use_class
styled_ostream_flush
styled_ostream_flush_to_current_style
styled_ostream_free
styled_ostream_get_hyperlink_id
styled_ostream_get_hyperlink_ref
styled_ostream_set_hyperlink
styled_ostream_write_mem

term_ostream_create
term_ostream_flush
term_ostream_flush_to_current_style
term_ostream_free
term_ostream_get_bgcolor
term_ostream_get_color
term_ostream_get_hyperlink_id
term_ostream_get_hyperlink_ref
term_ostream_get_posture
term_ostream_get_underline
term_ostream_get_weight
term_ostream_rgb_to_color
term_ostream_set_bgcolor
term_ostream_set_color
term_ostream_set_hyperlink
term_ostream_set_posture
term_ostream_set_underline
term_ostream_set_weight
term_ostream_write_mem

term_styled_ostream_begin_use_class
term_styled_ostream_create
term_styled_ostream_end_use_class
term_styled_ostream_flush_to_current_style
term_styled_ostream_flush
term_styled_ostream_free
term_styled_ostream_get_hyperlink_id
term_styled_ostream_get_hyperlink_ref
term_styled_ostream_set_hyperlink
term_styled_ostream_write_mem

handle_color_option
handle_style_option
print_color_test
style_file_prepare
styled_ostream_create
libtextstyle_isatty