EXPORTS
cleanup_temp_dir
close_stdout
compile_csharp_class
compile_java_class
copy_file_preserving
create_pipe_in
create_pipe_out
create_temp_dir
c_strcasecmp
c_strncasecmp
c_strstr
error
error_at_line
execute_csharp_program
execute_java_class
find_backup_file_name
find_in_path
fnmatch
fopen_supersede
fopen_temp
fread_file
freea
fstrcmp_bounded
full_write
fwriteerror
fwriteerror_supersede
fwriteerror_temp
gcd
glwthread_mutex_unlock
glwthread_mutex_init
glwthread_mutex_lock
gl_locale_name
hash_destroy
hash_find_entry
hash_init
hash_insert_entry
hash_iterate
hash_iterate_modify
hash_set_value
iconveh_close
iconveh_open
last_component
locale_charset
maybe_print_progname
multiline_error
multiline_warning
next_prime
pipe_filter_ii_execute
proper_name
proper_name_utf8
register_temp_file
register_temp_subdir
relocate
relocate2
rpl_access
rpl_close
rpl_fdopen
rpl_fopen
rpl_fprintf
rpl_fputc
rpl_fputs
rpl_ftell
rpl_fwrite
rpl_getline
rpl_getopt_long
rpl_localtime
rpl_malloc
rpl_mbrtowc
rpl_mbsinit
rpl_mkdir
rpl_open
rpl_printf
rpl_raise
rpl_realloc
rpl_setlocale
rpl_signal
rpl_stat
rpl_strerror
rpl_strstr
set_program_name_and_installdir
setlocale_null_r
shell_quote_argv
sigaddset
sigemptyset
sigprocmask
stpcpy
stpncpy
strchrnul
trim2
uc_is_java_whitespace
uc_is_space
uc_width
ulc_width_linebreaks
unicode_name_character
unregister_temp_file
unregister_temp_subdir
unsetenv
u8_check
u8_mbtoucr
u8_mbtouc_aux
u8_uctomb_aux
u16_mbtouc_aux
vasprintf
wait_subprocess
xalloc_die
xasprintf
xcalloc
xconcatenated_filename
xget_version
xmalloc
xmemdup
xmemdup0
xmem_cd_iconv
xmem_cd_iconveh
xmmalloca
xmlFreeDoc
xmlGetLastError
xmlGetLineNo
xmlReadFd
xmlFree
xmlFreeNs
xmlFreeTextWriter
xmlAddNextSibling
xmlAllocOutputBuffer
xmlCheckVersion
xmlCopyNamespace
xmlDocGetRootElement
xmlDocFormatDump
xmlGetNsList
xmlGetProp
xmlGetNsProp
xmlHasNsProp
xmlHasProp
xmlNewNode
xmlNewTextWriter
xmlNodeAddContent
xmlNodeGetContent
xmlOutputBufferGetContent
xmlReadFile
xmlReadMemory
xmlSetProp
xmlStrEqual
xmlTextWriterEndElement
xmlTextWriterStartElement
xmlTextWriterWriteAttribute
xmlTextWriterWriteRaw
xmlXPathEval
xmlXPathEvalExpression
xmlXPathFreeContext
xmlXPathFreeObject
xmlXPathNewContext
xmlXPathRegisterNs
xmlXPathSetContextNode
xrealloc
xsetenv
xstrdup
_obstack_begin
_obstack_free
_obstack_newchunk