/* DO NOT EDIT! GENERATED AUTOMATICALLY! */
/* OpenMP declarations.

   Copyright (C) 2019-2020 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

#if __GNUC__ >= 3

#endif


#ifndef _GL_OMP_H

/* The include_next requires a split double-inclusion guard.  */
#include "../include/omp.h"

#ifndef _GL_OMP_H
#define _GL_OMP_H

#ifdef __cplusplus
extern "C" {
#endif

/* Initializes environment variables necessary for OpenMP.  */
extern void openmp_init (void);

#ifdef __cplusplus
}
#endif

#endif /* _GL_OMP_H */
#endif /* _GL_OMP_H */
